==> paycenter-client-3.3.50-20210622.015805-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/duibaLive/mp/DuibaLiveMpChargeRequest.java <==
package cn.com.duiba.paycenter.dto.payment.charge.duibaLive.mp;

import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * @Author xujing
 * @Date 2021/5/18 1:57 下午
 */
public class DuibaLiveMpChargeRequest extends BaseChargeRequest {

    private static final long serialVersionUID = 8731482193855148950L;
    /**
     * 客户端ip
     */
    @Size(max = 16, message = "ip的长度超过16")
    private String ip;

    /**
     * openId
     */
    @NotNull(message = "用户openId不能为空")
    private String openId;

    /**
     * 商品描述
     */
    @Size(max = 255, message = "商品描述超过255")
    @NotNull(message = "商品详情不能为空")
    private String goodsDetail;

    /**
     * 商品id
     */
    @NotNull(message = "商品id不能为空")
    private Long goodsId;

    /**
     * 商品名称
     */
    @Size(max = 255, message = "商品名称超过255")
    @NotNull(message = "商品名称不能为空")
    private String goodsName;


    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getGoodsDetail() {
        return goodsDetail;
    }

    public void setGoodsDetail(String goodsDetail) {
        this.goodsDetail = goodsDetail;
    }

    public Long getGoodsId() {
        return goodsId;
    }

    public void setGoodsId(Long goodsId) {
        this.goodsId = goodsId;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }
}

==> paycenter-client-3.3.62-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/duibaLive/mp/DuibaLiveMpChargeRequest.java <==
package cn.com.duiba.paycenter.dto.payment.charge.duibaLive.mp;

import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;

/**
 * @Author xujing
 * @Date 2021/5/18 1:57 下午
 */
public class DuibaLiveMpChargeRequest extends BaseChargeRequest {

    private static final long serialVersionUID = 8731482193855148950L;
    /**
     * 客户端ip
     */
    @Size(max = 16, message = "ip的长度超过16")
    private String ip;

    /**
     * openId
     */
    @NotNull(message = "用户openId不能为空")
    private String openId;

    /**
     * userId
     */
    @NotNull(message = "用户Id不能为空")
    private Long userId;

    /**
     * 商品描述
     */
    @Size(max = 255, message = "商品描述超过255")
    @NotNull(message = "商品详情不能为空")
    private String goodsDetail;

    /**
     * 商品id
     */
    @NotNull(message = "商品id不能为空")
    private String goodsId;

    /**
     * 商品编码
     */
    private String merchantCoding;

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getGoodsDetail() {
        return goodsDetail;
    }

    public void setGoodsDetail(String goodsDetail) {
        this.goodsDetail = goodsDetail;
    }

    public String getGoodsId() {
        return goodsId;
    }

    public void setGoodsId(String goodsId) {
        this.goodsId = goodsId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getMerchantCoding() {
        return merchantCoding;
    }

    public void setMerchantCoding(String merchantCoding) {
        this.merchantCoding = merchantCoding;
    }
}
